Documentation
¶
Overview ¶
+groupName=oam.verrazzano.io
Package v1alpha1 contains API Schema definitions for the oam v1alpha1 API group +kubebuilder:object:generate=true +groupName=oam.verrazzano.io
Index ¶
- Constants
- Variables
- func QualifiedResourceRelationSlicesEquivalent(left []QualifiedResourceRelation, right []QualifiedResourceRelation) bool
- func QualifiedResourceRelationsContain(slice []QualifiedResourceRelation, find *QualifiedResourceRelation) bool
- type AuthorizationPolicy
- type AuthorizationRule
- type AuthorizationRuleCondition
- type AuthorizationRuleFrom
- type DeploymentTemplate
- type IngressDestination
- type IngressDestinationHTTPCookie
- type IngressPath
- type IngressRule
- type IngressSecurity
- type IngressTrait
- func (in *IngressTrait) DeepCopy() *IngressTrait
- func (in *IngressTrait) DeepCopyInto(out *IngressTrait)
- func (in *IngressTrait) DeepCopyObject() runtime.Object
- func (in *IngressTrait) GetCondition(ct oamrt.ConditionType) oamrt.Condition
- func (in *IngressTrait) GetWorkloadReference() oamrt.TypedReference
- func (in *IngressTrait) SetConditions(c ...oamrt.Condition)
- func (in *IngressTrait) SetWorkloadReference(r oamrt.TypedReference)
- func (r *IngressTrait) SetupWebhookWithManager(mgr ctrl.Manager) error
- func (r *IngressTrait) ValidateCreate() error
- func (r *IngressTrait) ValidateDelete() error
- func (r *IngressTrait) ValidateUpdate(old runtime.Object) error
- type IngressTraitList
- type IngressTraitSpec
- type IngressTraitStatus
- type LoggingTrait
- func (in *LoggingTrait) DeepCopy() *LoggingTrait
- func (in *LoggingTrait) DeepCopyInto(out *LoggingTrait)
- func (in *LoggingTrait) DeepCopyObject() runtime.Object
- func (in *LoggingTrait) GetCondition(ct oamrt.ConditionType) oamrt.Condition
- func (in *LoggingTrait) GetWorkloadReference() oamrt.TypedReference
- func (in *LoggingTrait) SetConditions(c ...oamrt.Condition)
- func (in *LoggingTrait) SetWorkloadReference(r oamrt.TypedReference)
- type LoggingTraitList
- type LoggingTraitSpec
- type LoggingTraitStatus
- type MetricsTrait
- func (in *MetricsTrait) DeepCopy() *MetricsTrait
- func (in *MetricsTrait) DeepCopyInto(out *MetricsTrait)
- func (in *MetricsTrait) DeepCopyObject() runtime.Object
- func (t *MetricsTrait) GetCondition(ct oamrt.ConditionType) oamrt.Condition
- func (t *MetricsTrait) GetWorkloadReference() oamrt.TypedReference
- func (t *MetricsTrait) SetConditions(c ...oamrt.Condition)
- func (t *MetricsTrait) SetWorkloadReference(r oamrt.TypedReference)
- type MetricsTraitList
- type MetricsTraitSpec
- type MetricsTraitStatus
- type PortSpec
- type QualifiedResourceRelation
- type ServiceTemplate
- type VerrazzanoCoherenceWorkload
- type VerrazzanoCoherenceWorkloadList
- type VerrazzanoCoherenceWorkloadSpec
- type VerrazzanoCoherenceWorkloadStatus
- type VerrazzanoHelidonWorkload
- type VerrazzanoHelidonWorkloadList
- type VerrazzanoHelidonWorkloadSpec
- type VerrazzanoHelidonWorkloadStatus
- type VerrazzanoWebLogicWorkload
- type VerrazzanoWebLogicWorkloadList
- type VerrazzanoWebLogicWorkloadSpec
- type VerrazzanoWebLogicWorkloadStatus
- type VerrazzanoWebLogicWorkloadTemplate
Constants ¶
const LoggingTraitKind string = "LoggingTrait"
LoggingTraitKind identifies the Kind for the LoggingTrait.
const MetricsTraitKind string = "MetricsTrait"
MetricsTraitKind identifies the Kind for the metrics trait.
Variables ¶
var ( // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = schema.GroupVersion{Group: "oam.verrazzano.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: SchemeGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func QualifiedResourceRelationSlicesEquivalent ¶
func QualifiedResourceRelationSlicesEquivalent(left []QualifiedResourceRelation, right []QualifiedResourceRelation) bool
QualifiedResourceRelationSlicesEquivalent determines if two slices of related resources are equivalent. The comparison does not depend on the order of the relations in the two slices. left - The first qualified resource relation for the equivalence comparison right - The second qualified resource relation for the equivalence comparison
func QualifiedResourceRelationsContain ¶
func QualifiedResourceRelationsContain(slice []QualifiedResourceRelation, find *QualifiedResourceRelation) bool
QualifiedResourceRelationsContain determines if a slice of relations contains a specific relation. slice - The slice of qualified resource relations to search find - The qualified resource relation to find in the slice
Types ¶
type AuthorizationPolicy ¶ added in v1.3.1
type AuthorizationPolicy struct {
// Rules are used to match requests from request principals to specific paths given an optional list of conditions.
Rules []*AuthorizationRule `json:"rules,omitempty"`
}
AuthorizationPolicy defines the set of rules for authorizing a request.
func (*AuthorizationPolicy) DeepCopy ¶ added in v1.3.1
func (in *AuthorizationPolicy) DeepCopy() *AuthorizationPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AuthorizationPolicy.
func (*AuthorizationPolicy) DeepCopyInto ¶ added in v1.3.1
func (in *AuthorizationPolicy) DeepCopyInto(out *AuthorizationPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AuthorizationRule ¶ added in v1.3.1
type AuthorizationRule struct {
// Specifies the request principals for access to a request. An asterisk (*) will match when the value is not empty,
// for example, if any request principal is found in the request.
From *AuthorizationRuleFrom `json:"from,omitempty"`
// Specifies a list of additional conditions for access to a request.
// +optional
When []*AuthorizationRuleCondition `json:"when,omitempty"`
}
AuthorizationRule matches requests from a list of request principals that access a specific path subject to a list of conditions.
func (*AuthorizationRule) DeepCopy ¶ added in v1.3.1
func (in *AuthorizationRule) DeepCopy() *AuthorizationRule
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AuthorizationRule.
func (*AuthorizationRule) DeepCopyInto ¶ added in v1.3.1
func (in *AuthorizationRule) DeepCopyInto(out *AuthorizationRule)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AuthorizationRuleCondition ¶ added in v1.3.1
type AuthorizationRuleCondition struct {
// The name of a request attribute.
Key string `json:"key,omitempty"`
// A list of allowed values for the attribute.
Values []string `json:"values,omitempty"`
}
AuthorizationRuleCondition provides additional required attributes for authorization.
func (*AuthorizationRuleCondition) DeepCopy ¶ added in v1.3.1
func (in *AuthorizationRuleCondition) DeepCopy() *AuthorizationRuleCondition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AuthorizationRuleCondition.
func (*AuthorizationRuleCondition) DeepCopyInto ¶ added in v1.3.1
func (in *AuthorizationRuleCondition) DeepCopyInto(out *AuthorizationRuleCondition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AuthorizationRuleFrom ¶ added in v1.3.1
type AuthorizationRuleFrom struct {
// Specifies the request principals for access to a request.
RequestPrincipals []string `json:"requestPrincipals,omitempty"`
}
AuthorizationRuleFrom includes a list of request principals.
func (*AuthorizationRuleFrom) DeepCopy ¶ added in v1.3.1
func (in *AuthorizationRuleFrom) DeepCopy() *AuthorizationRuleFrom
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AuthorizationRuleFrom.
func (*AuthorizationRuleFrom) DeepCopyInto ¶ added in v1.3.1
func (in *AuthorizationRuleFrom) DeepCopyInto(out *AuthorizationRuleFrom)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DeploymentTemplate ¶
type DeploymentTemplate struct {
// Metadata about a Helidon application.
// +kubebuilder:validation:Required
// +kubebuilder:pruning:PreserveUnknownFields
Metadata metav1.ObjectMeta `json:"metadata"`
// The pod spec of a Helidon application.
// +kubebuilder:validation:Required
PodSpec v1.PodSpec `json:"podSpec"`
// Label selector of a Helidon application.
// +optional
Selector metav1.LabelSelector `json:"selector,omitempty" patchStrategy:"retainKeys"`
// The replacement strategy of a Helidon application.
// +kubebuilder:validation:Optional
// +patchStrategy=retainKeys
// +optional
Strategy appsv1.DeploymentStrategy `json:"strategy,omitempty" patchStrategy:"retainKeys" protobuf:"bytes,4,opt,name=strategy"`
}
DeploymentTemplate specifies the metadata and pod spec of a Helidon workload.
func (*DeploymentTemplate) DeepCopy ¶
func (in *DeploymentTemplate) DeepCopy() *DeploymentTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DeploymentTemplate.
func (*DeploymentTemplate) DeepCopyInto ¶
func (in *DeploymentTemplate) DeepCopyInto(out *DeploymentTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IngressDestination ¶ added in v0.13.0
type IngressDestination struct {
// Destination host.
// +optional
Host string `json:"host,omitempty"`
// Session affinity cookie.
// +optional
HTTPCookie *IngressDestinationHTTPCookie `json:"httpCookie,omitempty"`
// Destination port.
// +optional
Port uint32 `json:"port,omitempty"`
}
IngressDestination specifies a specific destination host and port for the ingress paths. <div class="alert alert-warning" role="alert"> <h4 class="alert-heading">NOTE</h4> If there are multiple ports defined for a service, then the destination port must be specified OR the service port name must have the prefix `http`. </div>
func (*IngressDestination) DeepCopy ¶ added in v0.13.0
func (in *IngressDestination) DeepCopy() *IngressDestination
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressDestination.
func (*IngressDestination) DeepCopyInto ¶ added in v0.13.0
func (in *IngressDestination) DeepCopyInto(out *IngressDestination)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IngressDestinationHTTPCookie ¶ added in v1.2.0
type IngressDestinationHTTPCookie struct {
// The name of the HTTP cookie.
// +optional
Name string `json:"name,omitempty"`
// The path of the HTTP cookie.
// +optional
Path string `json:"path,omitempty"`
// The lifetime of the HTTP cookie (in seconds).
// +optional
TTL time.Duration `json:"ttl,omitempty"`
}
IngressDestinationHTTPCookie specifies a session affinity cookie for an ingress trait.
func (*IngressDestinationHTTPCookie) DeepCopy ¶ added in v1.2.0
func (in *IngressDestinationHTTPCookie) DeepCopy() *IngressDestinationHTTPCookie
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressDestinationHTTPCookie.
func (*IngressDestinationHTTPCookie) DeepCopyInto ¶ added in v1.2.0
func (in *IngressDestinationHTTPCookie) DeepCopyInto(out *IngressDestinationHTTPCookie)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IngressPath ¶
type IngressPath struct {
// If no path is provided, then it defaults to forward slash (`/`).
// +optional
Path string `json:"path,omitempty"`
// Path type values are case-sensitive and formatted as follows:
// <ul><li>`exact`: exact string match</li><li>`prefix`: prefix-based match</li><li>`regex`: regex-based match</li></ul>
// Defaults to `prefix` if `path` specified is `/`; otherwise, defaults to `exact`.
// +optional
PathType string `json:"pathType,omitempty"`
// Defines the set of rules for authorizing a request.
// +optional
Policy *AuthorizationPolicy `json:"authorizationPolicy,omitempty"`
}
IngressPath specifies a specific path to be exposed for an ingress trait.
func (*IngressPath) DeepCopy ¶
func (in *IngressPath) DeepCopy() *IngressPath
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressPath.
func (*IngressPath) DeepCopyInto ¶
func (in *IngressPath) DeepCopyInto(out *IngressPath)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IngressRule ¶
type IngressRule struct {
// The destination host and port for the ingress paths.
// +optional
Destination IngressDestination `json:"destination,omitempty"`
// One or more hosts exposed by the ingress trait. Wildcard hosts or hosts that are
// empty are filtered out. If there are no valid hosts provided, then a DNS host name
// is automatically generated and used.
// +optional
Hosts []string `json:"hosts,omitempty"`
// The paths to be exposed for an ingress trait.
Paths []IngressPath `json:"paths,omitempty"`
}
IngressRule specifies a rule for an ingress trait.
func (*IngressRule) DeepCopy ¶
func (in *IngressRule) DeepCopy() *IngressRule
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressRule.
func (*IngressRule) DeepCopyInto ¶
func (in *IngressRule) DeepCopyInto(out *IngressRule)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IngressSecurity ¶
type IngressSecurity struct {
// The name of a secret containing the certificate securing the transport. The specification of a secret here
// implies that a certificate was created for specific hosts, as specified in an [IngressRule](#oam.verrazzano.io/v1alpha1.IngressRule).
SecretName string `json:"secretName,omitempty"`
}
IngressSecurity specifies the secret containing the certificate securing the transport for an ingress trait.
func (*IngressSecurity) DeepCopy ¶
func (in *IngressSecurity) DeepCopy() *IngressSecurity
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressSecurity.
func (*IngressSecurity) DeepCopyInto ¶
func (in *IngressSecurity) DeepCopyInto(out *IngressSecurity)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IngressTrait ¶
type IngressTrait struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec IngressTraitSpec `json:"spec,omitempty"`
// The observed state of an ingress trait and related resources.
Status IngressTraitStatus `json:"status,omitempty"`
}
IngressTrait specifies the ingress traits API.
func (*IngressTrait) DeepCopy ¶
func (in *IngressTrait) DeepCopy() *IngressTrait
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressTrait.
func (*IngressTrait) DeepCopyInto ¶
func (in *IngressTrait) DeepCopyInto(out *IngressTrait)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IngressTrait) DeepCopyObject ¶
func (in *IngressTrait) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*IngressTrait) GetCondition ¶
func (in *IngressTrait) GetCondition(ct oamrt.ConditionType) oamrt.Condition
GetCondition gets the status condition of this ingress trait.
func (*IngressTrait) GetWorkloadReference ¶
func (in *IngressTrait) GetWorkloadReference() oamrt.TypedReference
GetWorkloadReference gets the workload reference of this ingress trait.
func (*IngressTrait) SetConditions ¶
func (in *IngressTrait) SetConditions(c ...oamrt.Condition)
SetConditions sets the status condition of this ingress trait.
func (*IngressTrait) SetWorkloadReference ¶
func (in *IngressTrait) SetWorkloadReference(r oamrt.TypedReference)
SetWorkloadReference sets the workload reference of this ingress trait.
func (*IngressTrait) SetupWebhookWithManager ¶
func (r *IngressTrait) SetupWebhookWithManager(mgr ctrl.Manager) error
SetupWebhookWithManager saves client from manager and sets up webhook
func (*IngressTrait) ValidateCreate ¶
func (r *IngressTrait) ValidateCreate() error
ValidateCreate implements webhook.Validator so a webhook will be registered for ingress trait type creation.
func (*IngressTrait) ValidateDelete ¶
func (r *IngressTrait) ValidateDelete() error
ValidateDelete implements webhook.Validator so a webhook will be registered for ingress trait type deletion.
func (*IngressTrait) ValidateUpdate ¶
func (r *IngressTrait) ValidateUpdate(old runtime.Object) error
ValidateUpdate implements webhook.Validator so a webhook will be registered for ingress trait type update.
type IngressTraitList ¶
type IngressTraitList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []IngressTrait `json:"items"`
}
IngressTraitList contains a list of IngressTraits.
func (*IngressTraitList) DeepCopy ¶
func (in *IngressTraitList) DeepCopy() *IngressTraitList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressTraitList.
func (*IngressTraitList) DeepCopyInto ¶
func (in *IngressTraitList) DeepCopyInto(out *IngressTraitList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IngressTraitList) DeepCopyObject ¶
func (in *IngressTraitList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IngressTraitSpec ¶
type IngressTraitSpec struct {
// A list of ingress rules for an ingress trait.
Rules []IngressRule `json:"rules,omitempty"`
// The security parameters for an ingress trait.
// This is required only if specific hosts are given in an [IngressRule](#oam.verrazzano.io/v1alpha1.IngressRule).
// +optional
TLS IngressSecurity `json:"tls,omitempty"`
// The WorkloadReference of the workload to which this trait applies.
// This value is populated by the OAM runtime when an ApplicationConfiguration
// resource is processed. When the ApplicationConfiguration is processed, a trait and
// a workload resource are created from the content of the ApplicationConfiguration.
// The WorkloadReference is provided in the trait by OAM to ensure that the trait controller
// can find the workload associated with the component containing the trait within the
// original ApplicationConfiguration.
WorkloadReference oamrt.TypedReference `json:"workloadRef"`
}
IngressTraitSpec specifies the desired state of an ingress trait.
func (*IngressTraitSpec) DeepCopy ¶
func (in *IngressTraitSpec) DeepCopy() *IngressTraitSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressTraitSpec.
func (*IngressTraitSpec) DeepCopyInto ¶
func (in *IngressTraitSpec) DeepCopyInto(out *IngressTraitSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IngressTraitStatus ¶
type IngressTraitStatus struct {
// Reconcile status of this ingress trait.
oamrt.ConditionedStatus `json:",inline"`
// The resources managed by this ingress trait.
Resources []oamrt.TypedReference `json:"resources,omitempty"`
}
IngressTraitStatus specifies the observed state of an ingress trait and related resources.
func (*IngressTraitStatus) DeepCopy ¶
func (in *IngressTraitStatus) DeepCopy() *IngressTraitStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressTraitStatus.
func (*IngressTraitStatus) DeepCopyInto ¶
func (in *IngressTraitStatus) DeepCopyInto(out *IngressTraitStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoggingTrait ¶ added in v1.1.0
type LoggingTrait struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec LoggingTraitSpec `json:"spec,omitempty"`
// The observed state of a logging trait and related resources.
Status LoggingTraitStatus `json:"status,omitempty"`
}
LoggingTrait specifies the logging traits API.
func (*LoggingTrait) DeepCopy ¶ added in v1.1.0
func (in *LoggingTrait) DeepCopy() *LoggingTrait
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingTrait.
func (*LoggingTrait) DeepCopyInto ¶ added in v1.1.0
func (in *LoggingTrait) DeepCopyInto(out *LoggingTrait)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoggingTrait) DeepCopyObject ¶ added in v1.1.0
func (in *LoggingTrait) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*LoggingTrait) GetCondition ¶ added in v1.1.0
func (in *LoggingTrait) GetCondition(ct oamrt.ConditionType) oamrt.Condition
GetCondition gets the status condition of this trait.
func (*LoggingTrait) GetWorkloadReference ¶ added in v1.1.0
func (in *LoggingTrait) GetWorkloadReference() oamrt.TypedReference
GetWorkloadReference gets the workload reference of this trait.
func (*LoggingTrait) SetConditions ¶ added in v1.1.0
func (in *LoggingTrait) SetConditions(c ...oamrt.Condition)
SetConditions sets the status condition of this trait.
func (*LoggingTrait) SetWorkloadReference ¶ added in v1.1.0
func (in *LoggingTrait) SetWorkloadReference(r oamrt.TypedReference)
SetWorkloadReference sets the workload reference of this trait.
type LoggingTraitList ¶ added in v1.1.0
type LoggingTraitList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []LoggingTrait `json:"items"`
}
+kubebuilder:object:root=true +kubebuilder:object:generate=true LoggingTraitList contains a list of LoggingTrait.
func (*LoggingTraitList) DeepCopy ¶ added in v1.1.0
func (in *LoggingTraitList) DeepCopy() *LoggingTraitList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingTraitList.
func (*LoggingTraitList) DeepCopyInto ¶ added in v1.1.0
func (in *LoggingTraitList) DeepCopyInto(out *LoggingTraitList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoggingTraitList) DeepCopyObject ¶ added in v1.1.0
func (in *LoggingTraitList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LoggingTraitSpec ¶ added in v1.1.0
type LoggingTraitSpec struct {
// The optional image pull policy for the Fluentd image provided by the user.
// +optional
ImagePullPolicy string `json:"imagePullPolicy,omitempty"`
// The configuration provided by the user for the Fluentd configuration that consists of
// fluentd.conf: `<source>\n ... and so on ...\n`.
LoggingConfig string `json:"loggingConfig,omitempty"`
// The name of the custom Fluentd image.
// +optional
LoggingImage string `json:"loggingImage,omitempty"`
// The WorkloadReference of the workload to which this trait applies.
// This value is populated by the OAM runtime when an ApplicationConfiguration
// resource is processed. When the ApplicationConfiguration is processed, a trait and
// a workload resource are created from the content of the ApplicationConfiguration.
// The WorkloadReference is provided in the trait by OAM to ensure that the trait controller
// can find the workload associated with the component containing the trait within the
// original ApplicationConfiguration.
WorkloadReference oamrt.TypedReference `json:"workloadRef"`
}
LoggingTraitSpec specifies the desired state of a logging trait.
func (*LoggingTraitSpec) DeepCopy ¶ added in v1.1.0
func (in *LoggingTraitSpec) DeepCopy() *LoggingTraitSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingTraitSpec.
func (*LoggingTraitSpec) DeepCopyInto ¶ added in v1.1.0
func (in *LoggingTraitSpec) DeepCopyInto(out *LoggingTraitSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoggingTraitStatus ¶ added in v1.1.0
type LoggingTraitStatus struct {
// Reconcile status of this logging trait.
oamrt.ConditionedStatus `json:",inline"`
// The resources managed by this logging trait.
Resources []oamrt.TypedReference `json:"resources,omitempty"`
}
LoggingTraitStatus specifies the observed state of a logging trait and related resources.
func (*LoggingTraitStatus) DeepCopy ¶ added in v1.1.0
func (in *LoggingTraitStatus) DeepCopy() *LoggingTraitStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingTraitStatus.
func (*LoggingTraitStatus) DeepCopyInto ¶ added in v1.1.0
func (in *LoggingTraitStatus) DeepCopyInto(out *LoggingTraitStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MetricsTrait ¶
type MetricsTrait struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec MetricsTraitSpec `json:"spec,omitempty"`
// The observed state of a metrics trait and related resources.
Status MetricsTraitStatus `json:"status,omitempty"`
}
MetricsTrait specifies the metrics trait API.
func (*MetricsTrait) DeepCopy ¶
func (in *MetricsTrait) DeepCopy() *MetricsTrait
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetricsTrait.
func (*MetricsTrait) DeepCopyInto ¶
func (in *MetricsTrait) DeepCopyInto(out *MetricsTrait)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MetricsTrait) DeepCopyObject ¶
func (in *MetricsTrait) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*MetricsTrait) GetCondition ¶
func (t *MetricsTrait) GetCondition(ct oamrt.ConditionType) oamrt.Condition
GetCondition gets the condition of this trait.
func (*MetricsTrait) GetWorkloadReference ¶
func (t *MetricsTrait) GetWorkloadReference() oamrt.TypedReference
GetWorkloadReference gets the workload reference of this trait.
func (*MetricsTrait) SetConditions ¶
func (t *MetricsTrait) SetConditions(c ...oamrt.Condition)
SetConditions sets the condition of this trait.
func (*MetricsTrait) SetWorkloadReference ¶
func (t *MetricsTrait) SetWorkloadReference(r oamrt.TypedReference)
SetWorkloadReference sets the workload reference of this trait.
type MetricsTraitList ¶
type MetricsTraitList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []MetricsTrait `json:"items"`
}
MetricsTraitList contains a list of MetricsTrait. +kubebuilder:object:root=true
func (*MetricsTraitList) DeepCopy ¶
func (in *MetricsTraitList) DeepCopy() *MetricsTraitList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetricsTraitList.
func (*MetricsTraitList) DeepCopyInto ¶
func (in *MetricsTraitList) DeepCopyInto(out *MetricsTraitList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MetricsTraitList) DeepCopyObject ¶
func (in *MetricsTraitList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MetricsTraitSpec ¶
type MetricsTraitSpec struct {
// Specifies whether metrics collection is enabled. Defaults to `true`.
//+optional
Enabled *bool `json:"enabled,omitempty"`
// The HTTP path for the related metrics endpoint. Defaults to `/metrics`.
// +optional
Path *string `json:"path,omitempty"`
// The HTTP port for the related metrics trait. Defaults to `8080`.
// +optional
Port *int `json:"port,omitempty"`
// The HTTP endpoints for the related metrics.
// +optional
Ports []PortSpec `json:"ports,omitempty"`
// The Prometheus deployment used to scrape the related metrics endpoints. By default, the Verrazzano-supplied
// Prometheus component is used to scrape the endpoint.
// +optional
Scraper *string `json:"scraper,omitempty"`
// The name of an opaque secret (for example, `username` and `password`) within the workload’s namespace for metrics
// endpoint access.
// +optional
Secret *string `json:"secret,omitempty"`
// The WorkloadReference of the workload to which this trait applies.
// This value is populated by the OAM runtime when an ApplicationConfiguration
// resource is processed. When the ApplicationConfiguration is processed, a trait and
// a workload resource are created from the content of the ApplicationConfiguration.
// The WorkloadReference is provided in the trait by OAM to ensure that the trait controller
// can find the workload associated with the component containing the trait within the
// original ApplicationConfiguration.
WorkloadReference oamrt.TypedReference `json:"workloadRef"`
}
MetricsTraitSpec specifies the desired state of a metrics trait.
func (*MetricsTraitSpec) DeepCopy ¶
func (in *MetricsTraitSpec) DeepCopy() *MetricsTraitSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetricsTraitSpec.
func (*MetricsTraitSpec) DeepCopyInto ¶
func (in *MetricsTraitSpec) DeepCopyInto(out *MetricsTraitSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MetricsTraitStatus ¶
type MetricsTraitStatus struct {
// Reconcile status of this metrics trait.
oamrt.ConditionedStatus `json:",inline"`
// Related resources affected by this metrics trait.
Resources []QualifiedResourceRelation `json:"resources,omitempty"`
}
MetricsTraitStatus defines the observed state of a metrics trait and related resources.
func (*MetricsTraitStatus) DeepCopy ¶
func (in *MetricsTraitStatus) DeepCopy() *MetricsTraitStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetricsTraitStatus.
func (*MetricsTraitStatus) DeepCopyInto ¶
func (in *MetricsTraitStatus) DeepCopyInto(out *MetricsTraitStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PortSpec ¶ added in v1.3.0
type PortSpec struct {
// The HTTP path for the related metrics endpoint. Defaults to `/metrics`.
// +optional
Path *string `json:"path,omitempty"`
// The HTTP port for the related metrics trait. Defaults to `8080`.
// +optional
Port *int `json:"port,omitempty"`
}
PortSpec defines an HTTP port and path combination.
func (*PortSpec) DeepCopy ¶ added in v1.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PortSpec.
func (*PortSpec) DeepCopyInto ¶ added in v1.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type QualifiedResourceRelation ¶
type QualifiedResourceRelation struct {
// API version of the related resource.
APIVersion string `json:"apiversion"`
// Kind of the related resource.
Kind string `json:"kind"`
// Name of the related resource.
Name string `json:"name"`
// Namespace of the related resource.
Namespace string `json:"namespace"`
// Role of the related resource, for example, `Deployment`.
Role string `json:"role"`
}
QualifiedResourceRelation identifies a specific related resource.
func (*QualifiedResourceRelation) DeepCopy ¶
func (in *QualifiedResourceRelation) DeepCopy() *QualifiedResourceRelation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new QualifiedResourceRelation.
func (*QualifiedResourceRelation) DeepCopyInto ¶
func (in *QualifiedResourceRelation) DeepCopyInto(out *QualifiedResourceRelation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ServiceTemplate ¶ added in v1.4.3
type ServiceTemplate struct {
// Metadata about a Helidon application.
// +kubebuilder:validation:Optional
// +optional
Metadata metav1.ObjectMeta `json:"metadata,omitempty"`
// The service spec of a Helidon application.
// +kubebuilder:validation:Optional
// +optional
ServiceSpec v1.ServiceSpec `json:"serviceSpec,omitempty"`
}
ServiceTemplate specifies the metadata and pod spec of a Helidon workload.
func (*ServiceTemplate) DeepCopy ¶ added in v1.4.3
func (in *ServiceTemplate) DeepCopy() *ServiceTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceTemplate.
func (*ServiceTemplate) DeepCopyInto ¶ added in v1.4.3
func (in *ServiceTemplate) DeepCopyInto(out *ServiceTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoCoherenceWorkload ¶
type VerrazzanoCoherenceWorkload struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// The desired state of a Verrazzano Coherence workload.
Spec VerrazzanoCoherenceWorkloadSpec `json:"spec,omitempty"`
// The observed state of a Verrazzano Coherence workload.
Status VerrazzanoCoherenceWorkloadStatus `json:"status,omitempty"`
}
VerrazzanoCoherenceWorkload specifies the Verrazzano Coherence workload API.
func (*VerrazzanoCoherenceWorkload) DeepCopy ¶
func (in *VerrazzanoCoherenceWorkload) DeepCopy() *VerrazzanoCoherenceWorkload
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoCoherenceWorkload.
func (*VerrazzanoCoherenceWorkload) DeepCopyInto ¶
func (in *VerrazzanoCoherenceWorkload) DeepCopyInto(out *VerrazzanoCoherenceWorkload)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoCoherenceWorkload) DeepCopyObject ¶
func (in *VerrazzanoCoherenceWorkload) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VerrazzanoCoherenceWorkloadList ¶
type VerrazzanoCoherenceWorkloadList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []VerrazzanoCoherenceWorkload `json:"items"`
}
VerrazzanoCoherenceWorkloadList contains a list of Verrazzano Coherence workload resources.
func (*VerrazzanoCoherenceWorkloadList) DeepCopy ¶
func (in *VerrazzanoCoherenceWorkloadList) DeepCopy() *VerrazzanoCoherenceWorkloadList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoCoherenceWorkloadList.
func (*VerrazzanoCoherenceWorkloadList) DeepCopyInto ¶
func (in *VerrazzanoCoherenceWorkloadList) DeepCopyInto(out *VerrazzanoCoherenceWorkloadList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoCoherenceWorkloadList) DeepCopyObject ¶
func (in *VerrazzanoCoherenceWorkloadList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VerrazzanoCoherenceWorkloadSpec ¶
type VerrazzanoCoherenceWorkloadSpec struct {
// The metadata and spec for the underlying
// <a href="https://oracle.github.io/coherence-operator/docs/latest/#/docs/about/04_coherence_spec">Coherence</a> resource.
// +kubebuilder:pruning:PreserveUnknownFields
Template runtime.RawExtension `json:"template"`
}
VerrazzanoCoherenceWorkloadSpec wraps a Coherence resource.
func (*VerrazzanoCoherenceWorkloadSpec) DeepCopy ¶
func (in *VerrazzanoCoherenceWorkloadSpec) DeepCopy() *VerrazzanoCoherenceWorkloadSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoCoherenceWorkloadSpec.
func (*VerrazzanoCoherenceWorkloadSpec) DeepCopyInto ¶
func (in *VerrazzanoCoherenceWorkloadSpec) DeepCopyInto(out *VerrazzanoCoherenceWorkloadSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoCoherenceWorkloadStatus ¶
type VerrazzanoCoherenceWorkloadStatus struct {
// The last generation of the Verrazzano Coherence workload that was reconciled.
LastGeneration string `json:"lastGeneration,omitempty"`
// The last value of the `verrazzano.io/restart-version` annotation.
LastRestartVersion string `json:"lastRestartVersion,omitempty"`
}
VerrazzanoCoherenceWorkloadStatus defines the observed state of a Verrazzano Coherence workload.
func (*VerrazzanoCoherenceWorkloadStatus) DeepCopy ¶
func (in *VerrazzanoCoherenceWorkloadStatus) DeepCopy() *VerrazzanoCoherenceWorkloadStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoCoherenceWorkloadStatus.
func (*VerrazzanoCoherenceWorkloadStatus) DeepCopyInto ¶
func (in *VerrazzanoCoherenceWorkloadStatus) DeepCopyInto(out *VerrazzanoCoherenceWorkloadStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoHelidonWorkload ¶
type VerrazzanoHelidonWorkload struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// The desired state of a Verrazzano Helidon workload.
// +kubebuilder:validation:Required
Spec VerrazzanoHelidonWorkloadSpec `json:"spec"`
// The observed state of a Verrazzano Helidon workload.
Status VerrazzanoHelidonWorkloadStatus `json:"status,omitempty"`
}
VerrazzanoHelidonWorkload specifies the Verrazzano Helidon workload API.
func (*VerrazzanoHelidonWorkload) DeepCopy ¶
func (in *VerrazzanoHelidonWorkload) DeepCopy() *VerrazzanoHelidonWorkload
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoHelidonWorkload.
func (*VerrazzanoHelidonWorkload) DeepCopyInto ¶
func (in *VerrazzanoHelidonWorkload) DeepCopyInto(out *VerrazzanoHelidonWorkload)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoHelidonWorkload) DeepCopyObject ¶
func (in *VerrazzanoHelidonWorkload) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VerrazzanoHelidonWorkloadList ¶
type VerrazzanoHelidonWorkloadList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []VerrazzanoHelidonWorkload `json:"items"`
}
VerrazzanoHelidonWorkloadList contains a list of Verrazzano Helidon workload resources. +kubebuilder:object:root=true
func (*VerrazzanoHelidonWorkloadList) DeepCopy ¶
func (in *VerrazzanoHelidonWorkloadList) DeepCopy() *VerrazzanoHelidonWorkloadList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoHelidonWorkloadList.
func (*VerrazzanoHelidonWorkloadList) DeepCopyInto ¶
func (in *VerrazzanoHelidonWorkloadList) DeepCopyInto(out *VerrazzanoHelidonWorkloadList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoHelidonWorkloadList) DeepCopyObject ¶
func (in *VerrazzanoHelidonWorkloadList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VerrazzanoHelidonWorkloadSpec ¶
type VerrazzanoHelidonWorkloadSpec struct {
// An embedded Helidon application deployment.
DeploymentTemplate DeploymentTemplate `json:"deploymentTemplate"`
// An embedded Helidon application service.
ServiceTemplate ServiceTemplate `json:"serviceTemplate,omitempty"`
}
VerrazzanoHelidonWorkloadSpec wraps a Helidon application deployment and service.
func (*VerrazzanoHelidonWorkloadSpec) DeepCopy ¶
func (in *VerrazzanoHelidonWorkloadSpec) DeepCopy() *VerrazzanoHelidonWorkloadSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoHelidonWorkloadSpec.
func (*VerrazzanoHelidonWorkloadSpec) DeepCopyInto ¶
func (in *VerrazzanoHelidonWorkloadSpec) DeepCopyInto(out *VerrazzanoHelidonWorkloadSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoHelidonWorkloadStatus ¶
type VerrazzanoHelidonWorkloadStatus struct {
// Reconcile status of this Verrazzano Helidon workload.
oamrt.ConditionedStatus `json:",inline"`
// The resources managed by this Verrazzano Helidon workload.
Resources []QualifiedResourceRelation `json:"resources,omitempty"`
}
VerrazzanoHelidonWorkloadStatus defines the observed state of Verrazzano Helidon workload.
func (*VerrazzanoHelidonWorkloadStatus) DeepCopy ¶
func (in *VerrazzanoHelidonWorkloadStatus) DeepCopy() *VerrazzanoHelidonWorkloadStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoHelidonWorkloadStatus.
func (*VerrazzanoHelidonWorkloadStatus) DeepCopyInto ¶
func (in *VerrazzanoHelidonWorkloadStatus) DeepCopyInto(out *VerrazzanoHelidonWorkloadStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoWebLogicWorkload ¶
type VerrazzanoWebLogicWorkload struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// The desired state of a Verrazzano WebLogic workload.
Spec VerrazzanoWebLogicWorkloadSpec `json:"spec,omitempty"`
// The observed state of a Verrazzano WebLogic workload.
Status VerrazzanoWebLogicWorkloadStatus `json:"status,omitempty"`
}
VerrazzanoWebLogicWorkload specifies the Verrazzano WebLogic workload API.
func (*VerrazzanoWebLogicWorkload) DeepCopy ¶
func (in *VerrazzanoWebLogicWorkload) DeepCopy() *VerrazzanoWebLogicWorkload
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoWebLogicWorkload.
func (*VerrazzanoWebLogicWorkload) DeepCopyInto ¶
func (in *VerrazzanoWebLogicWorkload) DeepCopyInto(out *VerrazzanoWebLogicWorkload)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoWebLogicWorkload) DeepCopyObject ¶
func (in *VerrazzanoWebLogicWorkload) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VerrazzanoWebLogicWorkloadList ¶
type VerrazzanoWebLogicWorkloadList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []VerrazzanoWebLogicWorkload `json:"items"`
}
VerrazzanoWebLogicWorkloadList contains a list of Verrazzano WebLogic workload resources.
func (*VerrazzanoWebLogicWorkloadList) DeepCopy ¶
func (in *VerrazzanoWebLogicWorkloadList) DeepCopy() *VerrazzanoWebLogicWorkloadList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoWebLogicWorkloadList.
func (*VerrazzanoWebLogicWorkloadList) DeepCopyInto ¶
func (in *VerrazzanoWebLogicWorkloadList) DeepCopyInto(out *VerrazzanoWebLogicWorkloadList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VerrazzanoWebLogicWorkloadList) DeepCopyObject ¶
func (in *VerrazzanoWebLogicWorkloadList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VerrazzanoWebLogicWorkloadSpec ¶
type VerrazzanoWebLogicWorkloadSpec struct {
// The metadata and spec for the underlying
// <a href="https://github.com/oracle/weblogic-kubernetes-operator/blob/main/documentation/domains/Domain.md">Domain</a> resource.
// +kubebuilder:pruning:PreserveUnknownFields
Template VerrazzanoWebLogicWorkloadTemplate `json:"template"`
Clusters []VerrazzanoWebLogicWorkloadTemplate `json:"clusters,omitempty"`
}
VerrazzanoWebLogicWorkloadSpec wraps a WebLogic resource. The WebLogic domain specified in the template must contain a spec field and it may include a metadata field.
func (*VerrazzanoWebLogicWorkloadSpec) DeepCopy ¶
func (in *VerrazzanoWebLogicWorkloadSpec) DeepCopy() *VerrazzanoWebLogicWorkloadSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoWebLogicWorkloadSpec.
func (*VerrazzanoWebLogicWorkloadSpec) DeepCopyInto ¶
func (in *VerrazzanoWebLogicWorkloadSpec) DeepCopyInto(out *VerrazzanoWebLogicWorkloadSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoWebLogicWorkloadStatus ¶
type VerrazzanoWebLogicWorkloadStatus struct {
// The last generation of the Verrazzano WebLogic workload that was reconciled.
LastGeneration string `json:"lastGeneration,omitempty"`
// The last value of the `verrazzano.io/restart-version` annotation.
LastRestartVersion string `json:"lastRestartVersion,omitempty"`
// The last value of the `verrazzano.io/lifecycle-action`.
LastLifecycleAction string `json:"lastLifecycleAction,omitempty"`
}
VerrazzanoWebLogicWorkloadStatus defines the observed state of a Verrazzano WebLogic workload.
func (*VerrazzanoWebLogicWorkloadStatus) DeepCopy ¶
func (in *VerrazzanoWebLogicWorkloadStatus) DeepCopy() *VerrazzanoWebLogicWorkloadStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoWebLogicWorkloadStatus.
func (*VerrazzanoWebLogicWorkloadStatus) DeepCopyInto ¶
func (in *VerrazzanoWebLogicWorkloadStatus) DeepCopyInto(out *VerrazzanoWebLogicWorkloadStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VerrazzanoWebLogicWorkloadTemplate ¶ added in v1.5.0
type VerrazzanoWebLogicWorkloadTemplate struct {
APIVersion string `json:"apiVersion,omitempty"`
// +kubebuilder:pruning:PreserveUnknownFields
Metadata runtime.RawExtension `json:"metadata,omitempty"`
// +kubebuilder:pruning:PreserveUnknownFields
Spec runtime.RawExtension `json:"spec"`
}
func (*VerrazzanoWebLogicWorkloadTemplate) DeepCopy ¶ added in v1.5.0
func (in *VerrazzanoWebLogicWorkloadTemplate) DeepCopy() *VerrazzanoWebLogicWorkloadTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VerrazzanoWebLogicWorkloadTemplate.
func (*VerrazzanoWebLogicWorkloadTemplate) DeepCopyInto ¶ added in v1.5.0
func (in *VerrazzanoWebLogicWorkloadTemplate) DeepCopyInto(out *VerrazzanoWebLogicWorkloadTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
Source Files
¶
- doc.go
- groupversion_info.go
- ingresstrait_authorization.go
- ingresstrait_methods.go
- ingresstrait_types.go
- ingresstrait_webhook.go
- loggingtrait_methods.go
- loggingtrait_types.go
- metricstrait_methods.go
- metricstrait_types.go
- status_types.go
- verrazzanocoherenceworkload_types.go
- verrazzanohelidonworkload_types.go
- verrazzanoweblogicworkload_types.go
- zz_generated.deepcopy.go