config

package
v1.7.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 9, 2024 License: UPL-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetClientID

func GetClientID() string

GetClientID returns the client ID

func GetExternalURL

func GetExternalURL() string

GetExternalURL returns the external URL of the OIDC provider

func GetServiceURL

func GetServiceURL() string

GetServiceURL returns the in-cluster service URL of the OIDC provider

func InitConfiguration

func InitConfiguration(log *zap.SugaredLogger) error

InitConfiguration loads the configuration from files and starts a goroutine to watch for configuration changes and reloads config values when changes are detected

Types

This section is empty.

Jump to