Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type VerrazzanoContext ¶
type VerrazzanoContext struct {
// Log is the logger for the execution context
Log vzlog.VerrazzanoLogger
// Client is a Kubernetes client
Client clipkg.Client
// DryRun will do a dry run of operations if true
DryRun bool
// ActualCR is the CR passed to top level Reconcile. It represents the desired Verrazzano state in the cluster
ActualCR *vzapi.Verrazzano
}
VerrazzanoContext the context needed to reconcile a Verrazzano CR
func NewVerrazzanoContext ¶
func NewVerrazzanoContext(log vzlog.VerrazzanoLogger, c clipkg.Client, actualCR *vzapi.Verrazzano, dryRun bool) (VerrazzanoContext, error)
NewVerrazzanoContext creates a VerrazzanoContext
Click to show internal directories.
Click to hide internal directories.