Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type IngressTraitExpansion
- type IngressTraitInterface
- type IngressTraitsGetter
- type LoggingTraitExpansion
- type LoggingTraitInterface
- type LoggingTraitsGetter
- type MetricsTraitExpansion
- type MetricsTraitInterface
- type MetricsTraitsGetter
- type OamV1alpha1Client
- func (c *OamV1alpha1Client) IngressTraits(namespace string) IngressTraitInterface
- func (c *OamV1alpha1Client) LoggingTraits(namespace string) LoggingTraitInterface
- func (c *OamV1alpha1Client) MetricsTraits(namespace string) MetricsTraitInterface
- func (c *OamV1alpha1Client) RESTClient() rest.Interface
- func (c *OamV1alpha1Client) VerrazzanoCoherenceWorkloads(namespace string) VerrazzanoCoherenceWorkloadInterface
- func (c *OamV1alpha1Client) VerrazzanoHelidonWorkloads(namespace string) VerrazzanoHelidonWorkloadInterface
- func (c *OamV1alpha1Client) VerrazzanoWebLogicWorkloads(namespace string) VerrazzanoWebLogicWorkloadInterface
- type OamV1alpha1Interface
- type VerrazzanoCoherenceWorkloadExpansion
- type VerrazzanoCoherenceWorkloadInterface
- type VerrazzanoCoherenceWorkloadsGetter
- type VerrazzanoHelidonWorkloadExpansion
- type VerrazzanoHelidonWorkloadInterface
- type VerrazzanoHelidonWorkloadsGetter
- type VerrazzanoWebLogicWorkloadExpansion
- type VerrazzanoWebLogicWorkloadInterface
- type VerrazzanoWebLogicWorkloadsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IngressTraitExpansion ¶
type IngressTraitExpansion interface{}
type IngressTraitInterface ¶
type IngressTraitInterface interface {
Create(ctx context.Context, ingressTrait *v1alpha1.IngressTrait, opts v1.CreateOptions) (*v1alpha1.IngressTrait, error)
Update(ctx context.Context, ingressTrait *v1alpha1.IngressTrait, opts v1.UpdateOptions) (*v1alpha1.IngressTrait, error)
UpdateStatus(ctx context.Context, ingressTrait *v1alpha1.IngressTrait, opts v1.UpdateOptions) (*v1alpha1.IngressTrait, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.IngressTrait, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.IngressTraitList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.IngressTrait, err error)
IngressTraitExpansion
}
IngressTraitInterface has methods to work with IngressTrait resources.
type IngressTraitsGetter ¶
type IngressTraitsGetter interface {
IngressTraits(namespace string) IngressTraitInterface
}
IngressTraitsGetter has a method to return a IngressTraitInterface. A group's client should implement this interface.
type LoggingTraitExpansion ¶
type LoggingTraitExpansion interface{}
type LoggingTraitInterface ¶
type LoggingTraitInterface interface {
Create(ctx context.Context, loggingTrait *v1alpha1.LoggingTrait, opts v1.CreateOptions) (*v1alpha1.LoggingTrait, error)
Update(ctx context.Context, loggingTrait *v1alpha1.LoggingTrait, opts v1.UpdateOptions) (*v1alpha1.LoggingTrait, error)
UpdateStatus(ctx context.Context, loggingTrait *v1alpha1.LoggingTrait, opts v1.UpdateOptions) (*v1alpha1.LoggingTrait, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.LoggingTrait, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.LoggingTraitList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.LoggingTrait, err error)
LoggingTraitExpansion
}
LoggingTraitInterface has methods to work with LoggingTrait resources.
type LoggingTraitsGetter ¶
type LoggingTraitsGetter interface {
LoggingTraits(namespace string) LoggingTraitInterface
}
LoggingTraitsGetter has a method to return a LoggingTraitInterface. A group's client should implement this interface.
type MetricsTraitExpansion ¶
type MetricsTraitExpansion interface{}
type MetricsTraitInterface ¶
type MetricsTraitInterface interface {
Create(ctx context.Context, metricsTrait *v1alpha1.MetricsTrait, opts v1.CreateOptions) (*v1alpha1.MetricsTrait, error)
Update(ctx context.Context, metricsTrait *v1alpha1.MetricsTrait, opts v1.UpdateOptions) (*v1alpha1.MetricsTrait, error)
UpdateStatus(ctx context.Context, metricsTrait *v1alpha1.MetricsTrait, opts v1.UpdateOptions) (*v1alpha1.MetricsTrait, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.MetricsTrait, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.MetricsTraitList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.MetricsTrait, err error)
MetricsTraitExpansion
}
MetricsTraitInterface has methods to work with MetricsTrait resources.
type MetricsTraitsGetter ¶
type MetricsTraitsGetter interface {
MetricsTraits(namespace string) MetricsTraitInterface
}
MetricsTraitsGetter has a method to return a MetricsTraitInterface. A group's client should implement this interface.
type OamV1alpha1Client ¶
type OamV1alpha1Client struct {
// contains filtered or unexported fields
}
OamV1alpha1Client is used to interact with features provided by the oam.verrazzano.io group.
func New ¶
func New(c rest.Interface) *OamV1alpha1Client
New creates a new OamV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*OamV1alpha1Client, error)
NewForConfig creates a new OamV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new OamV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *OamV1alpha1Client
NewForConfigOrDie creates a new OamV1alpha1Client for the given config and panics if there is an error in the config.
func (*OamV1alpha1Client) IngressTraits ¶
func (c *OamV1alpha1Client) IngressTraits(namespace string) IngressTraitInterface
func (*OamV1alpha1Client) LoggingTraits ¶
func (c *OamV1alpha1Client) LoggingTraits(namespace string) LoggingTraitInterface
func (*OamV1alpha1Client) MetricsTraits ¶
func (c *OamV1alpha1Client) MetricsTraits(namespace string) MetricsTraitInterface
func (*OamV1alpha1Client) RESTClient ¶
func (c *OamV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*OamV1alpha1Client) VerrazzanoCoherenceWorkloads ¶
func (c *OamV1alpha1Client) VerrazzanoCoherenceWorkloads(namespace string) VerrazzanoCoherenceWorkloadInterface
func (*OamV1alpha1Client) VerrazzanoHelidonWorkloads ¶
func (c *OamV1alpha1Client) VerrazzanoHelidonWorkloads(namespace string) VerrazzanoHelidonWorkloadInterface
func (*OamV1alpha1Client) VerrazzanoWebLogicWorkloads ¶
func (c *OamV1alpha1Client) VerrazzanoWebLogicWorkloads(namespace string) VerrazzanoWebLogicWorkloadInterface
type OamV1alpha1Interface ¶
type OamV1alpha1Interface interface {
RESTClient() rest.Interface
IngressTraitsGetter
LoggingTraitsGetter
MetricsTraitsGetter
VerrazzanoCoherenceWorkloadsGetter
VerrazzanoHelidonWorkloadsGetter
VerrazzanoWebLogicWorkloadsGetter
}
type VerrazzanoCoherenceWorkloadExpansion ¶
type VerrazzanoCoherenceWorkloadExpansion interface{}
type VerrazzanoCoherenceWorkloadInterface ¶
type VerrazzanoCoherenceWorkloadInterface interface {
Create(ctx context.Context, verrazzanoCoherenceWorkload *v1alpha1.VerrazzanoCoherenceWorkload, opts v1.CreateOptions) (*v1alpha1.VerrazzanoCoherenceWorkload, error)
Update(ctx context.Context, verrazzanoCoherenceWorkload *v1alpha1.VerrazzanoCoherenceWorkload, opts v1.UpdateOptions) (*v1alpha1.VerrazzanoCoherenceWorkload, error)
UpdateStatus(ctx context.Context, verrazzanoCoherenceWorkload *v1alpha1.VerrazzanoCoherenceWorkload, opts v1.UpdateOptions) (*v1alpha1.VerrazzanoCoherenceWorkload, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.VerrazzanoCoherenceWorkload, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.VerrazzanoCoherenceWorkloadList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.VerrazzanoCoherenceWorkload, err error)
VerrazzanoCoherenceWorkloadExpansion
}
VerrazzanoCoherenceWorkloadInterface has methods to work with VerrazzanoCoherenceWorkload resources.
type VerrazzanoCoherenceWorkloadsGetter ¶
type VerrazzanoCoherenceWorkloadsGetter interface {
VerrazzanoCoherenceWorkloads(namespace string) VerrazzanoCoherenceWorkloadInterface
}
VerrazzanoCoherenceWorkloadsGetter has a method to return a VerrazzanoCoherenceWorkloadInterface. A group's client should implement this interface.
type VerrazzanoHelidonWorkloadExpansion ¶
type VerrazzanoHelidonWorkloadExpansion interface{}
type VerrazzanoHelidonWorkloadInterface ¶
type VerrazzanoHelidonWorkloadInterface interface {
Create(ctx context.Context, verrazzanoHelidonWorkload *v1alpha1.VerrazzanoHelidonWorkload, opts v1.CreateOptions) (*v1alpha1.VerrazzanoHelidonWorkload, error)
Update(ctx context.Context, verrazzanoHelidonWorkload *v1alpha1.VerrazzanoHelidonWorkload, opts v1.UpdateOptions) (*v1alpha1.VerrazzanoHelidonWorkload, error)
UpdateStatus(ctx context.Context, verrazzanoHelidonWorkload *v1alpha1.VerrazzanoHelidonWorkload, opts v1.UpdateOptions) (*v1alpha1.VerrazzanoHelidonWorkload, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.VerrazzanoHelidonWorkload, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.VerrazzanoHelidonWorkloadList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.VerrazzanoHelidonWorkload, err error)
VerrazzanoHelidonWorkloadExpansion
}
VerrazzanoHelidonWorkloadInterface has methods to work with VerrazzanoHelidonWorkload resources.
type VerrazzanoHelidonWorkloadsGetter ¶
type VerrazzanoHelidonWorkloadsGetter interface {
VerrazzanoHelidonWorkloads(namespace string) VerrazzanoHelidonWorkloadInterface
}
VerrazzanoHelidonWorkloadsGetter has a method to return a VerrazzanoHelidonWorkloadInterface. A group's client should implement this interface.
type VerrazzanoWebLogicWorkloadExpansion ¶
type VerrazzanoWebLogicWorkloadExpansion interface{}
type VerrazzanoWebLogicWorkloadInterface ¶
type VerrazzanoWebLogicWorkloadInterface interface {
Create(ctx context.Context, verrazzanoWebLogicWorkload *v1alpha1.VerrazzanoWebLogicWorkload, opts v1.CreateOptions) (*v1alpha1.VerrazzanoWebLogicWorkload, error)
Update(ctx context.Context, verrazzanoWebLogicWorkload *v1alpha1.VerrazzanoWebLogicWorkload, opts v1.UpdateOptions) (*v1alpha1.VerrazzanoWebLogicWorkload, error)
UpdateStatus(ctx context.Context, verrazzanoWebLogicWorkload *v1alpha1.VerrazzanoWebLogicWorkload, opts v1.UpdateOptions) (*v1alpha1.VerrazzanoWebLogicWorkload, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.VerrazzanoWebLogicWorkload, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.VerrazzanoWebLogicWorkloadList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.VerrazzanoWebLogicWorkload, err error)
VerrazzanoWebLogicWorkloadExpansion
}
VerrazzanoWebLogicWorkloadInterface has methods to work with VerrazzanoWebLogicWorkload resources.
type VerrazzanoWebLogicWorkloadsGetter ¶
type VerrazzanoWebLogicWorkloadsGetter interface {
VerrazzanoWebLogicWorkloads(namespace string) VerrazzanoWebLogicWorkloadInterface
}
VerrazzanoWebLogicWorkloadsGetter has a method to return a VerrazzanoWebLogicWorkloadInterface. A group's client should implement this interface.