Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetExternalURL ¶
func GetExternalURL() string
GetExternalURL returns the external URL of the OIDC provider
func GetServiceURL ¶
func GetServiceURL() string
GetServiceURL returns the in-cluster service URL of the OIDC provider
func InitConfiguration ¶
func InitConfiguration(log *zap.SugaredLogger) error
InitConfiguration loads the configuration from files and starts a goroutine to watch for configuration changes and reloads config values when changes are detected
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.